package com.zhyc.module.biosafety.mapper;

import java.util.List;

import com.zhyc.module.biosafety.domain.Deworm;
import org.apache.ibatis.annotations.Mapper;

/**
 * 驱虫Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@Mapper
public interface DewormMapper 
{
    /**
     * 查询驱虫
     * 
     * @param id 驱虫主键
     * @return 驱虫
     */
    public Deworm selectDewormById(Long id);

    /**
     * 查询驱虫列表
     * 
     * @param deworm 驱虫
     * @return 驱虫集合
     */
    public List<Deworm> selectDewormList(Deworm deworm);

    /**
     * 新增驱虫
     * 
     * @param deworm 驱虫
     * @return 结果
     */
    public int insertDeworm(List<Deworm> deworm);

    /**
     * 修改驱虫
     * 
     * @param deworm 驱虫
     * @return 结果
     */
    public int updateDeworm(Deworm deworm);

    /**
     * 删除驱虫
     * 
     * @param id 驱虫主键
     * @return 结果
     */
    public int deleteDewormById(Long id);

    /**
     * 批量删除驱虫
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDewormByIds(Long[] ids);
}
